@@ -47,7 +47,7 @@ slope = function(x, na_flag = -9999) {
   # Checks
   if(inherits(x, "stars_proxy")) stop("'x' must be 'stars', not 'stars_proxy'")
   if(attr(st_dimensions(x), "raster")$curvilinear) stop("Curvilinear rasters are not supported.")
-  if(st_is_longlat(x)) stop("Rasters in geographical CRS are not supported.")
+  if(!is.na(st_is_longlat(x)) & st_is_longlat(x)) stop("Rasters in geographical CRS are not supported.")
   x = check_one_attribute(x)
   x = check_2d(x)
   stopifnot(is.numeric(na_flag))
